@@ -3,7 +3,8 @@ use std::{collections::BTreeMap, marker::PhantomData, sync::Arc};
 use async_trait::async_trait;
 use melnet::Request;
 use novasmt::{CompressedProof, ContentAddrStore};
-use themelio_stf::{AbbrBlock, BlockHeight, ConsensusProof, SealedState, Transaction};
+use themelio_stf::SealedState;
+use themelio_structs::{AbbrBlock, BlockHeight, ConsensusProof, Transaction};
 use tmelcrypt::HashVal;
 
 use crate::{NodeRequest, StateSummary, Substate};
@@ -66,7 +67,7 @@ impl<C: ContentAddrStore, S: NodeServer<C>> melnet::Endpoint<NodeRequest, Vec<u8
     async fn respond(&self, req: Request<NodeRequest>) -> anyhow::Result<Vec<u8>> {
         let state = req.state.clone();
         let server = self.server.clone();
-        smol::unblock(move || match req.body.clone() {
+        match req.body {
             NodeRequest::SendTx(tx) => {
                 server.send_tx(state, tx)?;
                 Ok(vec![])
@@ -90,7 +91,6 @@ impl<C: ContentAddrStore, S: NodeServer<C>> melnet::Endpoint<NodeRequest, Vec<u8
                     .retain(|h| hvv.binary_search(&h.hash_nosigs()).is_ok());
                 Ok(stdcode::serialize(&blk)?)
             }
-        })
-        .await
+        }
     }
 }
